@@ -1,6 +1,7 @@
 # Created by matveyev at 15.02.2021
 
 import h5py
+import os
 from contextlib import contextmanager
 import numpy as np
 
@@ -35,6 +36,16 @@ class FileFilter(QtCore.QSortFilterProxyModel):
 
             return match
 
+    # ----------------------------------------------------------------------
+    def lessThan(self, left, right):
+        left_name = self.sourceModel().data(left)
+        right_name = self.sourceModel().data(right)
+
+        left_is_dir = self.sourceModel().isDir(left)
+        right_is_dir = self.sourceModel().isDir(right)
+
+        return (not left_is_dir, left_name) < (not right_is_dir, right_name)
+
 
 # ----------------------------------------------------------------------
 def refresh_combo_box(combo, text):
